# 🙏 Please

[![Upload Python Package](https://github.com/av1ppp/please/actions/workflows/python-publish.yml/badge.svg)](https://github.com/av1ppp/please/actions/workflows/python-publish.yml)

Please is a simple task runner

### TODO

- Add dependency support
